@@ -10,17 +10,19 @@
 #include <QDateTime>
 #include <QDesktopServices>
 #include <QDir>
+#include <QMimeData>
 #include <QProcess>
 #include <QStandardPaths>
 #include <QTemporaryFile>
 
 #include <KApplicationTrader>
-#include <KFileUtils>
 #include <KIO/Job>
 #include <KIO/MkpathJob>
 #include <KJobTrackerInterface>
 #include <KLocalizedString>
+#include <KNotification>
 #include <KPluginFactory>
+#include <KSystemClipboard>
 
 #include "core/daemon.h"
 #include "core/filetransferjob.h"
@@ -57,9 +59,6 @@ QUrl SharePlugin::getFileDestination(const QString filename) const
     const QUrl dir = destinationDir().adjusted(QUrl::StripTrailingSlash);
     QUrl destination(dir);
     destination.setPath(dir.path() + QStringLiteral("/") + filename, QUrl::DecodedMode);
-    if (destination.isLocalFile() && QFile::exists(destination.toLocalFile())) {
-        destination.setPath(dir.path() + QStringLiteral("/") + KFileUtils::suggestName(dir, filename), QUrl::DecodedMode);
-    }
     return destination;
 }
 
@@ -125,11 +124,12 @@ bool SharePlugin::receivePacket(const NetworkPacket &np)
                 m_compositeJob = new CompositeFileTransferJob(device()->id());
                 m_compositeJob->setProperty("destUrl", destinationDir().toString());
                 m_compositeJob->setProperty("immediateProgressReporting", true);
-                KIO::getJobTracker()->registerJob(m_compositeJob);
+                Daemon::instance()->jobTracker()->registerJob(m_compositeJob);
             }
 
             FileTransferJob *job = np.createPayloadTransferJob(destination);
             job->setOriginName(device()->name() + QStringLiteral(": ") + filename);
+            job->setAutoRenameIfDestinatinonExists(true);
             connect(job, &KJob::result, this, [this, dateCreated, dateModified, open](KJob *job) -> void {
                 finished(job, dateCreated, dateModified, open);
             });
@@ -146,27 +146,59 @@ bool SharePlugin::receivePacket(const NetworkPacket &np)
     } else if (np.has(QStringLiteral("text"))) {
         QString text = np.get<QString>(QStringLiteral("text"));
 
-        KService::Ptr service = KApplicationTrader::preferredService(QStringLiteral("text/plain"));
-        const QString defaultApp = service ? service->desktopEntryName() : QString();
+        auto mimeData = new QMimeData;
+        mimeData->setText(text);
+        KSystemClipboard::instance()->setMimeData(mimeData, QClipboard::Clipboard);
 
-        if (defaultApp == QLatin1String("org.kde.kate") || defaultApp == QLatin1String("org.kde.kwrite")) {
-            QProcess *proc = new QProcess();
-            connect(proc, SIGNAL(finished(int)), proc, SLOT(deleteLater()));
-            proc->start(defaultApp.section(QStringLiteral("."), 2, 2), QStringList(QStringLiteral("--stdin")));
-            proc->write(text.toUtf8());
-            proc->closeWriteChannel();
-        } else {
-            QTemporaryFile tmpFile;
-            tmpFile.setFileTemplate(QStringLiteral("kdeconnect-XXXXXX.txt"));
-            tmpFile.setAutoRemove(false);
-            tmpFile.open();
-            tmpFile.write(text.toUtf8());
-            tmpFile.close();
-
-            const QString fileName = tmpFile.fileName();
-            Q_EMIT shareReceived(fileName);
-            QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
+        QUrl url;
+        QStringList lines = text.split(QStringLiteral("\n"), Qt::SkipEmptyParts);
+        if (lines.count()) {
+            url.setUrl(lines[lines.count() - 1].trimmed());
         }
+
+        KNotification *notif = new KNotification(QStringLiteral("textShareReceived"));
+        notif->setComponentName(QStringLiteral("kdeconnect"));
+        notif->setText(text);
+        notif->setTitle(i18nc("@info Some piece of text was received from a connected device", "Shared text from %1 copied to clipboard", device()->name()));
+        QStringList actions;
+        actions << i18nc("@action:button Edit text with default text editor", "Open in Text Editor");
+        if (url.isValid() && (url.scheme() == QStringLiteral("http") || url.scheme() == QStringLiteral("https"))) {
+            qDebug() << url;
+            actions << i18nc("@action:button Open URL with default app", "Open Link");
+        }
+        notif->setActions(actions);
+
+        connect(notif, &KNotification::action1Activated, this, [this, text]() {
+            KService::Ptr service = KApplicationTrader::preferredService(QStringLiteral("text/plain"));
+            const QString defaultApp = service ? service->desktopEntryName() : QString();
+
+            if (defaultApp == QLatin1String("org.kde.kate") || defaultApp == QLatin1String("org.kde.kwrite")) {
+                QProcess *proc = new QProcess();
+                connect(proc, SIGNAL(finished(int)), proc, SLOT(deleteLater()));
+                proc->start(defaultApp.section(QStringLiteral("."), 2, 2), QStringList(QStringLiteral("--stdin")));
+                proc->write(text.toUtf8());
+                proc->closeWriteChannel();
+            } else {
+                QTemporaryFile tmpFile;
+                tmpFile.setFileTemplate(QStringLiteral("kdeconnect-XXXXXX.txt"));
+                tmpFile.setAutoRemove(false);
+                tmpFile.open();
+                tmpFile.write(text.toUtf8());
+                tmpFile.close();
+
+                const QString fileName = tmpFile.fileName();
+                QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
+                Q_EMIT shareReceived(fileName);
+            }
+        });
+
+        connect(notif, &KNotification::action2Activated, this, [this, url]() {
+            QDesktopServices::openUrl(url);
+            Q_EMIT shareReceived(url.toString());
+        });
+
+        notif->sendEvent();
+
     } else if (np.has(QStringLiteral("url"))) {
         QUrl url = QUrl::fromEncoded(np.get<QByteArray>(QStringLiteral("url")));
         QDesktopServices::openUrl(url);
